@@ -3,9 +3,13 @@
 #' Get details such as when the video was published, the title, description, thumbnails, category etc.
 #' 
 #' @param video_id Comma separated list of IDs of the videos for which details are requested. Required. 
+#' @param part Comma-separated list of video resource properties requested. Options include:
+#' \code{contentDetails, fileDetails, id, liveStreamingDetails, localizations, player, processingDetails, 
+#' recordingDetails, snippet, statistics, status, suggestions, topicDetails}
 #' @param \dots Additional arguments passed to \code{\link{tuber_GET}}.
 #' 
-#' @return list with the following elements: \code{id} (video id that was passed), \code{publishedAt, channelId, title, description, thumbnails, 
+#' @return list. If part is snippet, the list will have the following elements: 
+#' \code{id} (video id that was passed), \code{publishedAt, channelId, title, description, thumbnails, 
 #' channelTitle, categoryId, liveBroadcastContent, localized, defaultAudioLanguage}
 #' 
 #' @export
@@ -18,13 +22,14 @@
 #' # Set API token via yt_oauth() first
 #' 
 #' get_video_details(video_id = "yJXTXN4xrI8")
+#' get_video_details(video_id = "yJXTXN4xrI8", part = "contentDetails")
 #' }
 
-get_video_details <- function(video_id = NULL, ...) {
+get_video_details <- function(video_id = NULL, part = "snippet", ...) {
 
   if (!is.character(video_id)) stop("Must specify a video ID.")
 
-  querylist <- list(part = "snippet", id = video_id)
+  querylist <- list(part = part, id = video_id)
 
   raw_res <- tuber_GET("videos",  querylist, ...)
 
@@ -34,7 +39,5 @@ get_video_details <- function(video_id = NULL, ...) {
       return(list())
     }
 
-  res <- raw_res$items[[1]]
-
-  c(id = res$id, res$snippet)
+  raw_res
 }
